@@ -138,7 +138,11 @@ IOReturn IOFWReadCommand::execute()
     if(!fFailOnReset) {
         // Update nodeID and generation
         fDevice->getNodeIDGeneration(fGeneration, fNodeID);
-		fSpeed = fControl->FWSpeed( fNodeID );    
+		fSpeed = fControl->FWSpeed( fNodeID );
+		if( fMembers->fMaxSpeed < fSpeed )
+		{
+			fSpeed = fMembers->fMaxSpeed;
+		} 
     }
 
     transfer = fSize;
